Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(472)

Unified Diff: remoting/signaling/signal_strategy.h

Issue 2798393007: Use SignalingAddress in SignalStrategy insterface. (Closed)
Patch Set: header Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/signaling/signal_strategy.h
diff --git a/remoting/signaling/signal_strategy.h b/remoting/signaling/signal_strategy.h
index 479f8b7a4ff68de589e5b041e2eac1169aaa230a..1edeeba0a20b3917fe59042f123008a8f9038425 100644
--- a/remoting/signaling/signal_strategy.h
+++ b/remoting/signaling/signal_strategy.h
@@ -16,6 +16,8 @@ class XmlElement;
namespace remoting {
+class SignalingAddress;
+
class SignalStrategy {
public:
enum State {
@@ -75,8 +77,8 @@ class SignalStrategy {
// Returns the last error. Set when state changes to DISCONNECT.
virtual Error GetError() const = 0;
- // Returns local JID or an empty string when not connected.
- virtual std::string GetLocalJid() const = 0;
+ // Local address. An empty value is returned when not connected.
+ virtual const SignalingAddress& GetLocalAddress() const = 0;
// Add a |listener| that can listen to all incoming
// messages. Doesn't take ownership of the |listener|. All listeners
« no previous file with comments | « remoting/signaling/push_notification_subscriber_unittest.cc ('k') | remoting/signaling/xmpp_signal_strategy.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698